@@ -1,5 +1,5 @@
 package App::gimpgitbuild::API::Worker;
-$App::gimpgitbuild::API::Worker::VERSION = '0.28.0';
+$App::gimpgitbuild::API::Worker::VERSION = '0.28.1';
 use strict;
 use warnings;
 use 5.014;
@@ -307,8 +307,11 @@ sub _run_the_mode_on_all_repositories
 {
     my ($worker) = @_;
 
-    $worker->_override_mode("clean_install");
-    $worker->_run_all();
+    if ( $worker->_mode() eq 'build' )
+    {
+        $worker->_override_mode("clean_install");
+        $worker->_run_all();
+    }
     $worker->_override_mode("");
     $worker->_run_all();
 
@@ -329,7 +332,7 @@ App::gimpgitbuild::API::Worker - common API
 
 =head1 VERSION
 
-version 0.28.0
+version 0.28.1
 
 =head1 METHODS
 
